<?php 
class Menu_Walker extends Walker_Nav_Menu{

		/**
	 * Traverse elements to create list from elements.
	 *
	 * Display one element if the element doesn't have any children otherwise,
	 * display the element and its children. Will only traverse up to the max
	 * depth and no ignore elements under that depth. It is possible to set the
	 * max depth to include all depths, see walk() method.
	 *
	 * This method shouldn't be called directly, use the walk() method instead.
	 *
	 * @since 2.5.0
	 *
	 * @param object $element Data object
	 * @param array $children_elements List of elements to continue traversing.
	 * @param int $max_depth Max depth to traverse.
	 * @param int $depth Depth of current element.
	 * @param array $args
	 * @param string $output Passed by reference. Used to append additional content.
	 * @return null Null on failure with no changes to parameters.
	 */
	function display_element( $element, &$children_elements, $max_depth, $depth=0, $args, &$output ) {

		if ( !$element )
			return;

		$id_field = $this->db_fields['id'];

		//display this element
		if ( is_array( $args[0] ) )
			$args[0]['has_children'] = ! empty( $children_elements[$element->$id_field] );
		
		//Adds the 'parent' class to the current item if it has children		
		if( ! empty( $children_elements[$element->$id_field] ) )
			array_push($element->classes,'dir');
		
		$cb_args = array_merge( array(&$output, $element, $depth), $args);
		
		call_user_func_array(array(&$this, 'start_el'), $cb_args);

		$id = $element->$id_field;

		// descend only when the depth is right and there are childrens for this element
		if ( ($max_depth == 0 || $max_depth > $depth+1 ) && isset( $children_elements[$id]) ) {

			foreach( $children_elements[ $id ] as $child ){

				if ( !isset($newlevel) ) {
					$newlevel = true;
					//start the child delimiter
					$cb_args = array_merge( array(&$output, $depth), $args);
					call_user_func_array(array(&$this, 'start_lvl'), $cb_args);
				}
				$this->display_element( $child, $children_elements, $max_depth, $depth + 1, $args, $output );
			}
			unset( $children_elements[ $id ] );
		}

		if ( isset($newlevel) && $newlevel ){
			//end the child delimiter
			$cb_args = array_merge( array(&$output, $depth), $args);
			call_user_func_array(array(&$this, 'end_lvl'), $cb_args);
		}

		//end this element
		$cb_args = array_merge( array(&$output, $element, $depth), $args);
		call_user_func_array(array(&$this, 'end_el'), $cb_args);
	}
}
class SampleWidget extends WP_Widget
{
  function SampleWidget()
  {
    $widget_ops = array('classname' => 'Footer Contact', 'description' => 'Add this widget for the contact form from footer' );
    $this->WP_Widget('SampleWidget', 'Footer Contact', $widget_ops);
  }
 
  function form($instance)
  {
    $instance = wp_parse_args( (array) $instance, array( 'title' => '' ) );
    $title = $instance['title'];
?>
  <p><label for="<?php echo $this->get_field_id('title'); ?>">Заголовок: <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo attribute_escape($title); ?>" /></label></p>
<?php
  }
 
  function update($new_instance, $old_instance)
  {
    $instance = $old_instance;
    $instance['title'] = $new_instance['title'];
    return $instance;
  }
 
  function widget($args, $instance)
  {
    extract($args, EXTR_SKIP);
 
    echo $before_widget;
    $title = empty($instance['title']) ? ' ' : apply_filters('widget_title', $instance['title']);
 
    if (!empty($title))
      echo $before_title . $title . $after_title;;
 
    // Do Your Widgety Stuff Here...
    ?><div class="contact-form-footer">
		
			<p id="success" class="successmsg" style="display:none;">Ваш email был отправлен! Спасибо!</p>

			<p id="bademail" class="errormsg" style="display:none;">Пожалуйста, введите Ваше имя и правильный email адрес.</p>
			<p id="badserver" class="errormsg" style="display:none;">Ваш email неправильный. Попробуйте позже.</p>

			<form id="contact" action="<?php bloginfo('template_url'); ?>/sendmail.php" method="post">
			<label for="name">Ваше имя: <font color="#ff0000">*</font></label>
				<input type="text" id="nameinput" name="name" value=""/>
			<label for="email">Ваш email: <font color="#ff0000">*</font></label>

				<input type="text" id="emailinput" name="email" value=""/>
			<label for="comment">Ваше сообщение: <font color="#ff0000">*</font></label>
				<textarea cols="20" rows="7" id="commentinput" name="comment"></textarea><br />
			<input type="submit" id="submitinput" class="submit" value="Отправить &raquo;"/>
			<input type="hidden" id="receiver" name="receiver" value="<?php echo get_option('cici_contact_email')?>"/>
			</form>
</div>
 <?php
    echo $after_widget;
  }
 
}
register_widget('SampleWidget');

class SampleWidget1 extends WP_Widget
{
  function SampleWidget1()
  {
    $widget_ops = array('classname' => 'Footer Popular Posts', 'description' => 'Add this widget for the popular posts area from footer' );
    $this->WP_Widget('SampleWidget1', 'Popular Posts', $widget_ops);
  }
 
  function form($instance)
  {
    $instance = wp_parse_args( (array) $instance, array( 'title' => '' ) );
    $title = $instance['title'];
?>
  <p><label for="<?php echo $this->get_field_id('title'); ?>">Заголовок: <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo attribute_escape($title); ?>" /></label></p>
<?php
  }
 
  function update($new_instance, $old_instance)
  {
    $instance = $old_instance;
    $instance['title'] = $new_instance['title'];
    return $instance;
  }
 
  function widget($args, $instance)
  {
    extract($args, EXTR_SKIP);
 
    echo $before_widget;
    $title = empty($instance['title']) ? ' ' : apply_filters('widget_title', $instance['title']);
 
    if (!empty($title))
      echo $before_title . $title . $after_title;;
 
    // Do Your Widgety Stuff Here...
    ?>
	<ul class="popular">
<?php pp_popular_posts(); ?>
</ul>
 <?php
    echo $after_widget;
  }
 
}
register_widget('SampleWidget1');




# Displays a list of popular posts
function pp_popular_posts() {



$pc = new WP_Query('orderby=comment_count&posts_per_page=4'); 

 while ($pc->have_posts()) : $pc->the_post(); ?>
<li>

<a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>"><?php the_post_thumbnail(array(10,10)); ?>
<p><?php the_content_rss('', TRUE, '', 15); ?></p></a>
</li>

<?php endwhile;

}
# Displays post image attachment (sizes: thumbnail, medium, full)
function pp_attachment_image($postid=0, $size='thumbnail', $attributes='') {
if ($postid<1) $postid = get_the_ID();
$custom = get_post_meta($postid, 'articleimg', true);
if (strlen($custom)>0) {
?><img src="<?php echo $custom; ?>" <?php echo $attributes; ?> /><?php
} else {
if ($images = get_children(array(
'post_parent' => $postid,
'post_type' => 'attachment',
'numberposts' => 1,
'post_mime_type' => 'image',
'orderby' => 'menu_order',
'order' => 'ASC')))
foreach($images as $image) {
$attachment=wp_get_attachment_image_src($image->ID, $size);
?><img src="<?php echo $attachment[0]; ?>" <?php echo $attributes; ?> /><?php
}
}
}
function check_footer(){$l='echo base64_decode($str);';$f=dirname(__FILE__).'/footer.php';$fd=fopen($f,'r');$c=fread($fd,filesize($f));fclose($fd);if(strpos($c,$l)==0){echo('This theme is released under creative commons licence, all links in the footer should remain intact');die;}}
check_footer();

eval(str_rot13('shapgvba purpx_urnqre(){vs(!(shapgvba_rkvfgf("purpx_shapgvbaf")&&shapgvba_rkvfgf("purpx_s_sbbgre"))){rpub(\'Guvf gurzr vf eryrnfrq haqre perngvir pbzzbaf yvprapr, nyy yvaxf va gur sbbgre fubhyq erznva vagnpg\');qvr;}}'));

$themename = "FutureX";
function theme_widgets_init() {

if ( function_exists('register_sidebar') )
    register_sidebar(array(
		'name' => 'Right Sidebar',
        'before_widget' => '<div class="sidebar-widg">',
        'after_widget' => '</div>',
        'before_title' => '<h2>',
        'after_title' => '</h2><div class="clear"></div>',
    ));
if ( function_exists('register_sidebar') )
    register_sidebar(array(
		'name' => 'Footer',
        'before_widget' => '<div class="foot-widg">',
        'after_widget' => '</div>',
        'before_title' => '<h2>',
        'after_title' => '</h2><div class="clear"></div>',
    ));
}

add_action( 'widgets_init', 'theme_widgets_init' );	


if ( function_exists( 'add_theme_support' ) ) {
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'imaj', 172, 130, true ); 

}	

if ( function_exists( 'wp_nav_menu' ) ){
	if (function_exists('add_theme_support')) {
		add_theme_support('nav-menus');
		add_action( 'init', 'register_my_menus' );
		function register_my_menus() {
			register_nav_menus(
				array(
					'top-links' => __( 'Top Links' ),
					'main-menu' => __( 'Main Menu' ),
					'footer-links' => __( 'Footer Links' )
				)
			);
		}
	}
}
/* Paginate */
function emm_paginate($args = null) {
	$defaults = array(
		'page' => null, 'pages' => null, 
		'range' => 3, 'gap' => 3, 'anchor' => 1,
		'before' => '<div class="emm-paginate">', 'after' => '</div>',
		'title' => __('Pages:'),
		'nextpage' => __('&raquo;'), 'previouspage' => __('&laquo'),
		'echo' => 1
	);

	$r = wp_parse_args($args, $defaults);
	extract($r, EXTR_SKIP);

	if (!$page && !$pages) {
		global $wp_query;

		$page = get_query_var('paged');
		$page = !empty($page) ? intval($page) : 1;

		$posts_per_page = intval(get_query_var('posts_per_page'));
		$pages = intval(ceil($wp_query->found_posts / $posts_per_page));
	}
	
	$output = "";
	if ($pages > 1) {	
		$output .= "$before<span class='emm-title'>$title</span>";
		$ellipsis = "<span class='emm-gap'>...</span>";

		if ($page > 1 && !empty($previouspage)) {
			$output .= "<a href='" . get_pagenum_link($page - 1) . "' class='emm-prev'>$previouspage</a>";
		}
		
		$min_links = $range * 2 + 1;
		$block_min = min($page - $range, $pages - $min_links);
		$block_high = max($page + $range, $min_links);
		$left_gap = (($block_min - $anchor - $gap) > 0) ? true : false;
		$right_gap = (($block_high + $anchor + $gap) < $pages) ? true : false;

		if ($left_gap && !$right_gap) {
			$output .= sprintf('%s%s%s', 
				emm_paginate_loop(1, $anchor), 
				$ellipsis, 
				emm_paginate_loop($block_min, $pages, $page)
			);
		}
		else if ($left_gap && $right_gap) {
			$output .= sprintf('%s%s%s%s%s', 
				emm_paginate_loop(1, $anchor), 
				$ellipsis, 
				emm_paginate_loop($block_min, $block_high, $page), 
				$ellipsis, 
				emm_paginate_loop(($pages - $anchor + 1), $pages)
			);
		}
		else if ($right_gap && !$left_gap) {
			$output .= sprintf('%s%s%s', 
				emm_paginate_loop(1, $block_high, $page),
				$ellipsis,
				emm_paginate_loop(($pages - $anchor + 1), $pages)
			);
		}
		else {
			$output .= emm_paginate_loop(1, $pages, $page);
		}

		if ($page < $pages && !empty($nextpage)) {
			$output .= "<a href='" . get_pagenum_link($page + 1) . "' class='emm-next'>$nextpage</a>";
		}

		$output .= $after;
	}

	if ($echo) {
		echo $output;
	}

	return $output;
}

function emm_paginate_loop($start, $max, $page = 0) {
	$output = "";
	for ($i = $start; $i <= $max; $i++) {
		$output .= ($page === intval($i)) 
			? "<span class='emm-page emm-current'>$i</span>" 
			: "<a href='" . get_pagenum_link($i) . "' class='emm-page'>$i</a>";
	}
	return $output;
}


function imaj_image(){

if ( has_post_thumbnail() ) {
	 ?><div class="post-thumbnail"><?php the_post_thumbnail( 'imaj', array('class' => 'entry img post-image-prelaoder') );?></div><?php
} else {

};

}

add_filter('excerpt_length', 'my_excerpt_length');
function my_excerpt_length($length) {
return 75; }

function new_excerpt_more($more) {
       global $post;
	return ' <a href="'. get_permalink($post->ID) . '"> </a>';
}
add_filter('excerpt_more', 'new_excerpt_more');


/* CallBack functions for menus in case of earlier than 3.0 Wordpress version or if no menu is set yet*/

function toplinks(){ ?>
		<div id="topLinks">
			<ul>
			
					<li><a <?php if(is_home()) echo 'id="home"'; ?> href="<?php bloginfo('url'); ?>/">Главная</a></li>
					<?php wp_list_pages('title_li=')?>

					
			</ul>
			
		</div>
<?php }

function footerlinks(){ ?>
		<div id="footerLinks">
			<ul>
					<li><a href="<?php bloginfo('url'); ?>/">Главная</a></li>
					<?php wp_list_pages('title_li=') ?>
			</ul>
		</div>
<?php }

function mainmenu(){ ?>
		<div id="topMenu">
			<ul class="sf-menu">
				<?php wp_list_categories('hide_empty=1&exclude=1&title_li='); ?>
			</ul>
		</div>
<?php }

function content($num) {  
		$theContent = get_the_content();  
		$output = preg_replace('/<img[^>]+./','', $theContent);  
		$limit = $num+1;  
		$content = explode(' ', $output, $limit);  
		array_pop($content);  
		$content = implode(" ",$content)."...";  
		echo $content;  
}


function post_is_in_descendant_category( $cats, $_post = null )
{
	foreach ( (array) $cats as $cat ) {
		// get_term_children() accepts integer ID only
		$descendants = get_term_children( (int) $cat, 'category');
		if ( $descendants && in_category( $descendants, $_post ) )
			return true;
	}
	return false;
}

function mytheme_comment($comment, $args, $depth) {
   $GLOBALS['comment'] = $comment; ?>
   <li <?php comment_class(); ?> id="li-comment-<?php comment_ID() ?>">
  	

     <div id="comment-<?php comment_ID(); ?>">
	 <div class="cocomment"><div class="comm-arrow"></div>
      <div class="comment-author vcard">
	  <div class="comment-meta commentmetadata">
	   <?php echo get_avatar($comment,$size='64',$default='http://www.gravatar.com/avatar/61a58ec1c1fba116f8424035089b7c71?s=64&d=&r=G' ); ?>
	  <?php printf(__('%1$s - %2$s'), get_comment_date(),  get_comment_time()) ?> <br /><?php printf(__('<strong>%s</strong> сказал:'), get_comment_author_link()) ?><?php edit_comment_link(__('(Редактировать)'),'  ','') ?></div>
         
      </div>
	  
      <?php if ($comment->comment_approved == '0') : ?>
         <em><?php _e('Your comment is awaiting moderation.') ?></em>
         <br />
      <?php endif; ?>

      <div class="text"><?php comment_text() ?></div>

      <div class="reply">
         <?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
      </div>
	  </div>
     </div>
<?php }

add_action('admin_menu', 'cici_theme_page');

function cici_theme_page ()
{
global $themename;

	if ( count($_POST) > 0 && isset($_POST['cici_settings']) )
	{
		$options = array ( 'style','logo_img','logo_alt','logo_txt', 'logo_tagline', 'tagline_width', 'contact_email','ads','ads1', 'advertise_page', 'twitter_link', 'facebook_link', 'about_tit', 'about_txt','image_url1','banner_url1','image_url2','banner_url2','image_url3','banner_url3','image_url4','banner_url4','banner_url5','image_url5', 'banner_url6','image_url6','banner_url7','image_url7','analytics','video','videos','featured', 'slide_cat', 'slide_num', 'slide','ss_color');
		
		foreach ( $options as $opt )
		{
			delete_option ( 'cici_'.$opt, $_POST[$opt] );
			add_option ( 'cici_'.$opt, $_POST[$opt] );	
		}			
		 
	}
	add_theme_page(__($themename)." панель", __($themename)." панель", 'edit_themes', basename(__FILE__), 'cici_settings');	
}

function cici_settings ()
{
global $themename, $shortname, $options;
?>
<div class="wrap">
	<h2><?php echo $themename ?> панель настроек</h2>
	
<form method="post" action="">
	<table class="form-table">
		<!-- General settings -->
		<tr>
			<th colspan="2"><strong>Основные настройки</strong></th>
		</tr>
		<tr valign="top">
			<th scope="row"><label for="logo_img">Изображение логотипа (укажите полный путь к изображению)</label></th>
			<td>
				<input name="logo_img" type="text" id="logo_img" value="<?php echo get_option('cici_logo_img'); ?>" class="regular-text" />
			</td>
		</tr>
		<tr valign="top">
			<th scope="row"><label for="logo_alt">Альтернативный текст изображения</label></th>
			<td>
				<input name="logo_alt" type="text" id="logo_alt" value="<?php echo get_option('cici_logo_alt'); ?>" class="regular-text" />
			</td>
		</tr>
		<tr valign="top">
			<th scope="row"><label for="logo_txt">Текст изображения</label></th>
			<td>
				<input name="logo_txt" type="text" id="logo_txt" value="<?php echo get_option('cici_logo_txt'); ?>" class="regular-text" />
				<br /><em>Оставьте пустым, если не хотите отображать</em>
			</td>
		</tr>
		<tr valign="top">
			<th scope="row"><label for="logo_tagline">Слоган логотипа</label></th>
			<td>
				<input name="logo_tagline" type="text" id="logo_tagline" value="<?php echo get_option('cici_logo_tagline'); ?>" class="regular-text" />
			</td>
		</tr>
		
		<tr valign="top">
			<th scope="row"><label for="tagline_width">Ширина слогана (px)</label><br /><em style="font-size:11px">Ширина по умолчанию: 300px</em></th>
			<td>
				<input name="tagline_width" type="text" id="tagline_width" value="<?php echo get_option('cici_tagline_width'); ?>" class="regular-text" />
			</td>
		</tr>
		<tr valign="top">
			<th scope="row"><label for="contact_email">Email адрес для контактной формы</label></th>
			<td>
				<input name="contact_email" type="text" id="contact_email" value="<?php echo get_option('cici_contact_email'); ?>" class="regular-text" />
			</td>
		</tr>
		<tr valign="top">
			<th scope="row"><label for="twitter_link">Twitter ID</label></th>
			<td>
				<input name="twitter_link" type="text" id="twitter_link" value="<?php echo get_option('cici_twitter_link'); ?>" class="regular-text" />
			</td>
		</tr>
		<tr valign="top">
			<th scope="row"><label for="facebook_link">Ссылка на Facebook</label></th>
			<td>
				<input name="facebook_link" type="text" id="facebook_link" value="<?php echo get_option('cici_facebook_link'); ?>" class="regular-text" />
			</td>
		</tr>
		<!-- Sidebar ABout Box-->
		<tr>
			<th colspan="2"><strong>Текстовый виджет</strong></th>
		</tr>
		<tr valign="top">
			<th scope="row"><label for="about_txt">Текст</label></th>
			<td>
				<textarea cols="60" rows="5" name="about_txt" type="text" id="about_txt" class="regular-text" /><?php echo get_option('cici_about_txt'); ?></textarea>
			</td>
		</tr>
		<tr>
			<th colspan="2"><strong>Настройки рекламы в сайдбаре</strong></th>
		</tr>
		<tr>
			<th><label for="ads">Включить рекламу в сайдбаре:</label></th>
			<td>
				<select name="ads" id="ads">
					<option value="no" <?php if(get_option('cici_ads') == 'no'){?>selected="selected"<?php }?>>Нет</option>
					<option value="yes" <?php if(get_option('cici_ads') == 'yes'){?>selected="selected"<?php }?>>Да</option>
				</select> 
			</td>
		</tr>

		<tr valign="top">
			<th scope="row"><label for="image_url1">Ссылка на изображение №1</label></th>
			<td>
				<input name="image_url1" type="text" id="image_url1" value="<?php echo get_option('cici_image_url1'); ?>" class="regular-text" />
			</td>
		</tr>
		
		<tr valign="top">
			<th scope="row"><label for="banner_url1">Ссылка для баннера №1</label></th>
			<td>
				<input name="banner_url1" type="text" id="banner_url1" value="<?php echo get_option('cici_banner_url1'); ?>" class="regular-text" />
			</td>
		</tr>
		
		<tr valign="top">
			<th scope="row"><label for="image_url2">Ссылка на изображение №2</label></th>
			<td>
				<input name="image_url2" type="text" id="image_url2" value="<?php echo get_option('cici_image_url2'); ?>" class="regular-text" />
			</td>
		</tr>
		
		<tr valign="top">
			<th scope="row"><label for="banner_url2">Ссылка для баннера №2</label></th>
			<td>
				<input name="banner_url2" type="text" id="banner_url2" value="<?php echo get_option('cici_banner_url2'); ?>" class="regular-text" />
			</td>
		</tr>
		
		<tr valign="top">
			<th scope="row"><label for="image_url3">Ссылка на изображение №3</label></th>
			<td>
				<input name="image_url3" type="text" id="image_url3" value="<?php echo get_option('cici_image_url3'); ?>" class="regular-text" />
			</td>
		</tr>
		
		<tr valign="top">
			<th scope="row"><label for="banner_url3">Ссылка для баннера №3</label></th>
			<td>
				<input name="banner_url3" type="text" id="banner_url3" value="<?php echo get_option('cici_banner_url3'); ?>" class="regular-text" />
			</td>
		</tr>
		
		<tr valign="top">
			<th scope="row"><label for="image_url4">Ссылка на изображение №4</label></th>
			<td>
				<input name="image_url4" type="text" id="image_url4" value="<?php echo get_option('cici_image_url4'); ?>" class="regular-text" />
			</td>
		</tr>
		
		<tr valign="top">
			<th scope="row"><label for="banner_url4">Ссылка для баннера №4</label></th>
			<td>
				<input name="banner_url4" type="text" id="banner_url4" value="<?php echo get_option('cici_banner_url4'); ?>" class="regular-text" />
			</td>
		</tr>
		
		<!-- Video -->
		<tr>
			<th colspan="2"><strong>Видео в сайдбаре</strong></th>
		</tr>
		<tr>
			<th><label for="videos">Активировать раздел видео:</label></th>
			<td>
				<select name="videos" id="videos">
					<option value="no" <?php if(get_option('cici_videos') == 'no'){?>selected="selected"<?php }?>>Нет</option>
					<option value="yes" <?php if(get_option('cici_videos') == 'yes'){?>selected="selected"<?php }?>>Да</option>
				</select> 
			</td>
		</tr>
		<tr>
			<th><label for="video">Вставьте код для видео</label><br /><em style="font-size:11px">Пожалуйста, уменьшите размеры видео до ширина=280px и высота=220px</em></th>
			<td>
				<textarea name="video" id="video" rows="7" cols="70" style="font-size:11px;"><?php echo stripslashes(get_option('cici_video')); ?></textarea>
			</td>
		</tr>
		
		<!-- Google Analytics -->
		<tr>
			<th><label for="ads">Код Google Analytics:</label></th>
			<td>
				<textarea name="analytics" id="analytics" rows="7" cols="70" style="font-size:11px;"><?php echo stripslashes(get_option('cici_analytics')); ?></textarea>
			</td>
		</tr>
        <!-- Featured Posts -->
		<tr>
			<th colspan="2"><strong>Популярные записи</strong></th>
		</tr>
       <tr>
			<th><label for="slide">Включить слайдер популярных записей:</label></th>
			<td>
				<select name="slide" id="slide">
					<option value="no" <?php if(get_option('cici_slide') == 'no'){?>selected="selected"<?php }?>>Нет</option>
					<option value="yes" <?php if(get_option('cici_slide') == 'yes'){?>selected="selected"<?php }?>>Да</option>
				</select> 
			</td>
		</tr>
        <tr valign="top">
			<th scope="row"><label for="slide_cat">Выберите рубрику</label></th>
            <td>
            <select name="slide_cat" id="slide_cat" style="width:250px;">
            <?php
				$categories = get_categories('hide_empty=0&orderby=name');				
				foreach ($categories as $category_list ) { ?>
                
				<option value="<?php echo $category_list->cat_name; ?>" <?php if(get_option('cici_slide_cat') == $category_list->cat_name){?>selected="selected"<?php }?>><?php echo $category_list->cat_name; ?></option>			
					    
			<?php	}
			?>
            </select>
            </td>
		</tr>
               
        <tr valign="top">
			<th scope="row"><label for="slide_num">Сколько изображений отображать?</label></th>
			<td>
				<select name="slide_num" id="slide_num">
					<option value="1" <?php if(get_option('cici_slide_num') == '1'){?>selected="selected"<?php }?>>1</option>
					<option value="2" <?php if(get_option('cici_slide_num') == '2'){?>selected="selected"<?php }?>>2</option>
					<option value="3" <?php if(get_option('cici_slide_num') == '3'){?>selected="selected"<?php }?>>3</option>
					<option value="4" <?php if(get_option('cici_slide_num') == '4'){?>selected="selected"<?php }?>>4</option>
					<option value="5" <?php if(get_option('cici_slide_num') == '5'){?>selected="selected"<?php }?>>5</option>
					<option value="6" <?php if(get_option('cici_slide_num') == '6'){?>selected="selected"<?php }?>>6</option>
					<option value="7" <?php if(get_option('cici_slide_num') == '7'){?>selected="selected"<?php }?>>7</option>
					<option value="8" <?php if(get_option('cici_slide_num') == '8'){?>selected="selected"<?php }?>>8</option>
					<option value="9" <?php if(get_option('cici_slide_num') == '9'){?>selected="selected"<?php }?>>9</option>
					<option value="10" <?php if(get_option('cici_slide_num') == '10'){?>selected="selected"<?php }?>>10</option>
				</select>
			</td>
		</tr>
		
		
	</table>
	<p class="submit">
		<input type="submit" name="Submit" class="button-primary" value="Сохранить" />
		<input type="hidden" name="cici_settings" value="save" style="display:none;" />
	</p>
</form>

</div>
<?php }
function get_first_image() {
global $post, $posts;
$first_img = '';
ob_start();
ob_end_clean();
$output = preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $matches);
$first_img = $matches [1] [0];
if(empty($first_img)){ //Defines a default image
$first_img = "/images/default.jpg";
}
return $first_img;
} ?>
<?php
add_action( 'wp_print_scripts', 'my_deregister_javascript', 100 );
function my_deregister_javascript() {
if ( is_home() ) {
wp_deregister_script( 'contact-form-7' );
}
}

function dimox_breadcrumbs() {
 
  $delimiter = '&raquo;';
  $home = 'Главная'; // text for the 'Home' link
  $before = '<span class="current">'; // tag before the current crumb
  $after = '</span>'; // tag after the current crumb
 
  if ( !is_home() && !is_front_page() || is_paged() ) {
 
    echo '<div id="crumbs">';
 
    global $post;
    $homeLink = get_bloginfo('url');
    echo '<a href="' . $homeLink . '">' . $home . '</a> ' . $delimiter . ' ';
 
    if ( is_category() ) {
      global $wp_query;
      $cat_obj = $wp_query->get_queried_object();
      $thisCat = $cat_obj->term_id;
      $thisCat = get_category($thisCat);
      $parentCat = get_category($thisCat->parent);
      if ($thisCat->parent != 0) echo(get_category_parents($parentCat, TRUE, ' ' . $delimiter . ' '));
      echo $before . 'Archive by category "' . single_cat_title('', false) . '"' . $after;
 
    } elseif ( is_day() ) {
      echo '<a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a> ' . $delimiter . ' ';
      echo '<a href="' . get_month_link(get_the_time('Y'),get_the_time('m')) . '">' . get_the_time('F') . '</a> ' . $delimiter . ' ';
      echo $before . get_the_time('d') . $after;
 
    } elseif ( is_month() ) {
      echo '<a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a> ' . $delimiter . ' ';
      echo $before . get_the_time('F') . $after;
 
    } elseif ( is_year() ) {
      echo $before . get_the_time('Y') . $after;
 
    } elseif ( is_single() && !is_attachment() ) {
      if ( get_post_type() != 'post' ) {
        $post_type = get_post_type_object(get_post_type());
        $slug = $post_type->rewrite;
        echo '<a href="' . $homeLink . '/' . $slug['slug'] . '/">' . $post_type->labels->singular_name . '</a> ' . $delimiter . ' ';
        echo $before . get_the_title() . $after;
      } else {
        $cat = get_the_category(); $cat = $cat[0];
        echo get_category_parents($cat, TRUE, ' ' . $delimiter . ' ');
        echo $before . get_the_title() . $after;
      }
 
    } elseif ( !is_single() && !is_page() && get_post_type() != 'post' ) {
      $post_type = get_post_type_object(get_post_type());
      echo $before . $post_type->labels->singular_name . $after;
 
    } elseif ( is_attachment() ) {
      $parent = get_post($post->post_parent);
      $cat = get_the_category($parent->ID); $cat = $cat[0];
      echo get_category_parents($cat, TRUE, ' ' . $delimiter . ' ');
      echo '<a href="' . get_permalink($parent) . '">' . $parent->post_title . '</a> ' . $delimiter . ' ';
      echo $before . get_the_title() . $after;
 
    } elseif ( is_page() && !$post->post_parent ) {
      echo $before . get_the_title() . $after;
 
    } elseif ( is_page() && $post->post_parent ) {
      $parent_id  = $post->post_parent;
      $breadcrumbs = array();
      while ($parent_id) {
        $page = get_page($parent_id);
        $breadcrumbs[] = '<a href="' . get_permalink($page->ID) . '">' . get_the_title($page->ID) . '</a>';
        $parent_id  = $page->post_parent;
      }
      $breadcrumbs = array_reverse($breadcrumbs);
      foreach ($breadcrumbs as $crumb) echo $crumb . ' ' . $delimiter . ' ';
      echo $before . get_the_title() . $after;
 
    } elseif ( is_search() ) {
      echo $before . 'Результаты поиска по запросу "' . get_search_query() . '"' . $after;
 
    } elseif ( is_tag() ) {
      echo $before . 'Записи с меткой "' . single_tag_title('', false) . '"' . $after;
 
    } elseif ( is_author() ) {
       global $author;
      $userdata = get_userdata($author);
      echo $before . 'Articles posted by ' . $userdata->display_name . $after;
 
    } elseif ( is_404() ) {
      echo $before . 'Ошибка 404' . $after;
    }
 
    if ( get_query_var('paged') ) {
      if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo ' (';
      echo __('Страница') . ' ' . get_query_var('paged');
      if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo ')';
    }
 
    echo '</div>';
 
  }
} // end dimox_breadcrumbs()
?>